@@ -1,13 +1,11 @@
-expect_error(esp_get_hypsobath(epsg = 3367))
-expect_error(esp_get_hypsobath(spatialtype = "f"))
-expect_error(esp_get_hypsobath(resolution = "10"))
-
-
 test_that("hypsobath online", {
-  skip_if_not(
-    giscoR::gisco_check_access(),
-    "Skipping... GISCO not reachable."
-  )
+  expect_error(esp_get_hypsobath(epsg = 3367))
+  expect_error(esp_get_hypsobath(spatialtype = "f"))
+  expect_error(esp_get_hypsobath(resolution = "10"))
+
+  skip_on_cran()
+  skip_if_siane_offline()
+  skip_if_gisco_offline()
 
   expect_silent(esp_get_hypsobath(
     spatialtype = "line",
